<?php function elitepress_header_customizer( $wp_customize ) {
	
if ( ! class_exists( 'WP_Customize_Control' ) ) {
	return;
}

/**
 * Radio image customize control.
 *
 * @since  1.1.24
 * @access public
 */
class Elitepress_Customize_Control_Radio_Image extends WP_Customize_Control {
	/**
	 * The type of customize control being rendered.
	 *
	 * @since 1.1.24
	 * @var   string
	 */
	public $type = 'radio-image';
	/**
	 * Displays the control content.
	 *
	 * @since  1.1.24
	 * @access public
	 * @return void
	 */
	public function render_content() {
		/* If no choices are provided, bail. */
		if ( empty( $this->choices ) ) {
			return;
		} ?>

		<?php if ( ! empty( $this->label ) ) : ?>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
		<?php endif; ?>

		<?php if ( ! empty( $this->description ) ) : ?>
			<span class="description customize-control-description"><?php echo $this->description; ?></span>
		<?php endif; ?>

		<div id="<?php echo esc_attr( "input_{$this->id}" ); ?>">

			<?php foreach ( $this->choices as $value => $args ) : ?>

				<input type="radio" disabled value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( "_customize-radio-{$this->id}" ); ?>" id="<?php echo esc_attr( "{$this->id}-{$value}" ); ?>" <?php $this->link(); ?> <?php checked( $this->value(), $value ); ?> />

				<label for="<?php echo esc_attr( "{$this->id}-{$value}" ); ?>">
					<?php if ( ! empty( $args['label'] ) ) { ?>
						<span class="screen-reader-text"><?php echo esc_html( $args['label'] ); ?></span>
						<?php
}
?>
					<img src="<?php echo esc_url( sprintf( $args['url'], get_template_directory_uri(), get_stylesheet_directory_uri() ) ); ?>" 
											<?php
											if ( ! empty( $args['label'] ) ) {
												echo 'alt="' . esc_attr( $args['label'] ) . '"'; }
?>
	/>
				</label>

			<?php endforeach; ?>

		</div><!-- .image -->

		<script type="text/javascript">
			jQuery( document ).ready( function() {
				jQuery( '#<?php echo esc_attr( "input_{$this->id}" ); ?>' ).buttonset();
			} );
		</script>
	<?php
	}
	/**
	 * Loads the jQuery UI Button script and hooks our custom styles in.
	 *
	 * @since  1.1.24
	 * @access public
	 * @return void
	 */
	public function enqueue() {
		wp_enqueue_script( 'jquery-ui-button' );
		add_action( 'customize_controls_print_styles', array( $this, 'print_styles' ) );
	}
	/**
	 * Outputs custom styles to give the selected image a visible border.
	 *
	 * @since  1.1.24
	 * @access public
	 * @return void
	 */
	public function print_styles() {
	?>

		<style type="text/css" id="hybrid-customize-radio-image-css">
			.customize-control-radio-image .ui-buttonset {
				text-align: center;
			}

			.customize-control-radio-image label {
				display: inline-block;
				max-width: 33.3%;
				padding: 3px;
				font-size: inherit;
				line-height: inherit;
				height: auto;
				cursor: pointer;
				border-width: 0;
				-webkit-appearance: none;
				-webkit-border-radius: 0;
				border-radius: 0;
				white-space: nowrap;
				-webkit-box-sizing: border-box;
				-moz-box-sizing: border-box;
				box-sizing: border-box;
				color: inherit;
				background: none;
				-webkit-box-shadow: none;
				box-shadow: none;
				vertical-align: inherit;
			}

			.customize-control-radio-image label:first-of-type {
				float: left;
			}
			.customize-control-radio-image label:nth-of-type(n + 3){
				float: right;
			}

			.customize-control-radio-image label:hover {
				background: none;
				border-color: inherit;
				color: inherit;
			}

			.customize-control-radio-image label:active {
				background: none;
				border-color: inherit;
				-webkit-box-shadow: none;
				box-shadow: none;
				-webkit-transform: none;
				-ms-transform: none;
				transform: none;
			}

			.customize-control-radio-image img { border: 1px solid transparent; }
			.customize-control-radio-image .ui-state-active img {
				border-color: #5b9dd9;
				-webkit-box-shadow: 0 0 3px rgba(0,115,170,.8);
				box-shadow: 0 0 3px rgba(0,115,170,.8);
			}
		</style>
	<?php
	}
}

	
	

/* Header Section */
	$wp_customize->add_panel( 'header_options', array(
		'priority'       => 200,
		'capability'     => 'edit_theme_options',
		'title'      => __('Header settings', 'elitepress'),
	) );
	
	
	/* favicon option */
    $wp_customize->add_section( 'elitepress_favicon' , array(
      'title'       => __('Site favicon', 'elitepress' ),
      'priority'    => 300,
	  'panel'  => 'header_options',
    ) );
    
    $wp_customize->add_setting('elitepress_lite_options[upload_image_favicon]', array(
      'sanitize_callback' => 'esc_url_raw',
	   'capability'     => 'edit_theme_options',
	   'type' => 'option', 
    ) );
    
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'elitepress_lite_options[upload_image_favicon]', array(
      'label'    => __('Site favicon', 'elitepress' ),
      'section'  => 'elitepress_favicon',
    ) ) );
	
	
	//Header logo setting
	$wp_customize->add_section( 'header_logo' , array(
		'title'      => __('Header logo settings', 'elitepress'),
		'panel'  => 'header_options',
		'priority'   => 400,
   	) );
	$wp_customize->add_setting(
		'elitepress_lite_options[upload_image_logo]'
		, array(
        'capability'     => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw',
		'type' => 'option',
    ));
	
	$wp_customize->add_control(
		   new WP_Customize_Image_Control(
			   $wp_customize,
			   'elitepress_lite_options[upload_image_logo]',
			   array(
				   'label'          => __('Upload logo','elitepress' ),
				   'section'        => 'header_logo',
				   'priority'   => 50,
			   )
		   )
	);
	
	//Enable/Disable logo text
	$wp_customize->add_setting(
    'elitepress_lite_options[text_title]',array(
	'default'    => false,
	'sanitize_callback' => 'sanitize_text_field',
	'type' => 'option'
	));

	$wp_customize->add_control(
    'elitepress_lite_options[text_title]',
    array(
        'type' => 'checkbox',
        'label' => __('Show Logo text','elitepress'),
        'section' => 'header_logo',
		'priority'   => 100,
    )
	);
	
	
	//Logo width
	
	$wp_customize->add_setting(
    'elitepress_lite_options[width]',array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' => 100,
	'type' => 'option',
	
	));

	$wp_customize->add_control(
    'elitepress_lite_options[width]',
    array(
        'type' => 'text',
        'label' => __('Enter Logo width','elitepress'),
        'section' => 'header_logo',
		'priority'   => 400,
    )
	);
	
	//Logo Height
	$wp_customize->add_setting(
    'elitepress_lite_options[height]',array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' => 50,
	'type'=>'option',
	
	));

	$wp_customize->add_control(
    'elitepress_lite_options[height]',
    array(
        'type' => 'text',
        'label' => __('Enter Logo Height','elitepress'),
        'section' => 'header_logo',
		'priority'   =>410,
    )
	);
	
	if ( class_exists( 'Elitepress_Customize_Control_Radio_Image' ) ) {
		$wp_customize->add_setting(
			'logo_alignment', array(
				'default'           => 'left',
				'sanitize_callback' => 'elitepress_sanitize_radio',
			)
		);

		$wp_customize->add_control(
			new Elitepress_Customize_Control_Radio_Image(
				$wp_customize, 'logo_alignment', array(
					'label'    => esc_html__('Header Layout', 'elitepress' ),
					'priority' => 411,
					'section' => 'header_logo',
					'choices' => array(
						'left' => array(
							'url' => trailingslashit( get_template_directory_uri() ) . 'images/left.png',
						),
						'center' => array(
							'url' => trailingslashit( get_template_directory_uri() ) . 'images/center.png',
						),
						'right' => array(
							'url' => trailingslashit( get_template_directory_uri() ) . 'images/right.png',
						),
					),
				)
			)
		);
	}
	
    $wp_customize->add_setting(
	'elitepress_lite_options[google_analytics]', array(
		'capability'     => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
		'type' => 'option',
    ));
	$wp_customize->add_control('elitepress_lite_options[google_analytics]', array(
        'label'   => __('Google tracking code', 'elitepress'),
        'section' => 'header_logo',
        'type'    => 'textarea',
		'priority'   => 412,
		'input_attrs' => array('disabled' => 'disabled'),));
	
	
	//Custom css
	$wp_customize->add_section( 'custom_css' , array(
		'title'      => __('Custom CSS', 'elitepress'),
		'panel'  => 'header_options',
		'priority'   => 100,
   	) );
	$wp_customize->add_setting(
	'elitepress_lite_options[webrit_custom_css]'
		, array(
        'capability'     => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
		'type'=> 'option',
    ));
    $wp_customize->add_control( 'elitepress_lite_options[webrit_custom_css]', array(
        'label'   => __('Custom CSS', 'elitepress'),
        'section' => 'custom_css',
        'type' => 'textarea',
		'priority'   => 100,
    )); 	
	
	//Header Search bar

	$wp_customize->add_section(
        'header_search_bar',
        array(
            'title' => 'Search Bar ',
           'priority'    => 400,
			'panel' => 'header_options',
        )
    );
	
	
	//Show and hide Header Search Bar
	$wp_customize->add_setting(
	'elitepress_lite_options[header_search_bar_enabled]'
    ,
    array(
        'default' => true,
		'capability'     => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
		'type' => 'option',
    )	
	);
	$wp_customize->add_control(
    'elitepress_lite_options[header_search_bar_enabled]',
    array(
        'label' => __('Enable search bar on header','elitepress'),
        'section' => 'header_search_bar',
        'type' => 'checkbox',
    )
	);
	
		// adding upgrade to por message for slider
	class WP_Header_pro_Customize_Control extends WP_Customize_Control {
    public $type = 'new_menu';
    /**
    * Render the control's content.
    */
		public function render_content() {
		?>
			 <div class="pro-version">
			 <p><?php _e('To want use more below header options click to upgrade to pro','elitepress');?></p>
			 </div>
			  <div class="pro-box">
			 <a href="<?php echo esc_url('http://webriti.com/elitepress/');?>" class="service" id="review_pro" target="_blank"><?php _e( 'Upgrade to Pro','elitepress' ); ?></a>
			 <div>
			<?php
		}
    }

	$wp_customize->add_setting(
		'header_upgrade',
		array(
			'capability'     => 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
		)	
	);
	$wp_customize->add_control( new WP_Header_pro_Customize_Control( $wp_customize, 'header_upgrade', array(	
			'section' => 'header_logo',
			'setting' => 'header_upgrade',
			'priority' => 410,
	
	)));

	
	}
	add_action( 'customize_register', 'elitepress_header_customizer' );
	
	function elitepress_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
    }

    function elitepress_sanitize_radio( $input, $setting ){
         
            //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
            $input = sanitize_key($input);
 
            //get the list of possible radio box options 
            $choices = $setting->manager->get_control( $setting->id )->choices;
                             
            //return input if valid or return default option
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );                
             
    }
	
	
	
	?>